@@ -8,7 +8,7 @@ static R_CallMethodDef CallEntries[] = {
 
     {"RGDAL_Init", (DL_FUNC) &RGDAL_Init, 0},
     {"RGDAL_Exit", (DL_FUNC) &RGDAL_Exit, 0},
-    {"checkCRSArgs", (DL_FUNC) &checkCRSArgs, 1},
+    {"RGDAL_checkCRSArgs", (DL_FUNC) &RGDAL_checkCRSArgs, 1},
     {"RGDAL_GetDescription", (DL_FUNC) &RGDAL_GetDescription, 1},
     {"RGDAL_GDALVersionInfo", (DL_FUNC) &RGDAL_GDALVersionInfo, 1},
     {"RGDAL_GDALCheckVersion", (DL_FUNC) &RGDAL_GDALCheckVersion, 0},
@@ -29,7 +29,7 @@ static R_CallMethodDef CallEntries[] = {
     {"RGDAL_GetRasterYSize", (DL_FUNC) &RGDAL_GetRasterYSize, 1},
     {"RGDAL_GetRasterXSize", (DL_FUNC) &RGDAL_GetRasterXSize, 1},
     {"RGDAL_GetRasterCount", (DL_FUNC) &RGDAL_GetRasterCount, 1},
-    {"RGDAL_GetProjectionRef", (DL_FUNC) &RGDAL_GetProjectionRef, 1},
+    {"RGDAL_GetProjectionRef", (DL_FUNC) &RGDAL_GetProjectionRef, 2},
     {"RGDAL_PutRasterData", (DL_FUNC) &RGDAL_PutRasterData, 3},
     {"RGDAL_GetRasterData", (DL_FUNC) &RGDAL_GetRasterData, 4},
     {"RGDAL_GetScale", (DL_FUNC) &RGDAL_GetScale, 1},
@@ -48,29 +48,39 @@ static R_CallMethodDef CallEntries[] = {
     {"RGDAL_CPLSetConfigOption", (DL_FUNC) &RGDAL_CPLSetConfigOption, 2},
     {"RGDAL_CPL_RECODE_ICONV", (DL_FUNC) &RGDAL_CPL_RECODE_ICONV, 0},
     {"PROJcopyEPSG", (DL_FUNC) &PROJcopyEPSG, 1},
-    {"ogrInfo", (DL_FUNC) &ogrInfo, 2},
+    {"RGDAL_ogrInfo", (DL_FUNC) &RGDAL_ogrInfo, 2},
     {"R_OGR_types", (DL_FUNC) &R_OGR_types, 2},
-    {"ogrFIDs", (DL_FUNC) &ogrFIDs, 2},
+    {"RGDAL_ogrFIDs", (DL_FUNC) &RGDAL_ogrFIDs, 2},
     {"ogr_GetDriverNames", (DL_FUNC) &ogr_GetDriverNames, 0},
-    {"ogrP4S", (DL_FUNC) &ogrP4S, 2},
-    {"ogrListLayers", (DL_FUNC) &ogrListLayers, 1},
+    {"ogrP4S", (DL_FUNC) &ogrP4S, 4},
+    {"RGDAL_ogrListLayers", (DL_FUNC) &RGDAL_ogrListLayers, 1},
     {"ogrDataFrame", (DL_FUNC) &ogrDataFrame, 4},
     {"R_OGR_CAPI_features", (DL_FUNC) &R_OGR_CAPI_features, 3},
     {"make_Polygonlist", (DL_FUNC) &make_Polygonlist, 2},
     {"p4s_to_wkt", (DL_FUNC) &p4s_to_wkt, 2},
     {"wkt_to_p4s", (DL_FUNC) &wkt_to_p4s, 2},
+    {"P6_SRID_show", (DL_FUNC) &P6_SRID_show, 6},
+//    {"P6_SRID_proj", (DL_FUNC) &P6_SRID_proj, 6},
+    {"list_coordinate_ops", (DL_FUNC) &list_coordinate_ops, 5},
     {"ogrAutoIdentifyEPSG", (DL_FUNC) &ogrAutoIdentifyEPSG, 1},
     {"OGR_write", (DL_FUNC) &OGR_write, 1},
-    {"ogrDeleteLayer", (DL_FUNC) &ogrDeleteLayer, 3},
-    {"ogrDeleteDataSource", (DL_FUNC) &ogrDeleteDataSource, 2},
+    {"RGDAL_ogrDeleteLayer", (DL_FUNC) &RGDAL_ogrDeleteLayer, 3},
+    {"RGDAL_ogrDeleteDataSource", (DL_FUNC) &RGDAL_ogrDeleteDataSource, 2},
     {"ogrCheckExists", (DL_FUNC) &ogrCheckExists, 2},
+    {"R_GDAL_OSR_PROJ", (DL_FUNC) &R_GDAL_OSR_PROJ, 0},
     {"PROJ4VersionInfo", (DL_FUNC) &PROJ4VersionInfo, 0},
     {"PROJ4NADsInstalled", (DL_FUNC) &PROJ4NADsInstalled, 0},
+    {"get_proj_search_path", (DL_FUNC) &get_proj_search_path, 0},
     {"PROJ4_proj_def_dat_Installed", (DL_FUNC) &PROJ4_proj_def_dat_Installed, 0},
     {"transform", (DL_FUNC) &transform, 6},
-    {"projInfo", (DL_FUNC) &projInfo, 1},
-    {"project", (DL_FUNC) &project, 5},
+    {"transform_ng", (DL_FUNC) &transform_ng, 7},
+    {"RGDAL_projInfo", (DL_FUNC) &RGDAL_projInfo, 1},
+    {"RGDAL_project", (DL_FUNC) &RGDAL_project, 5},
     {"project_inv", (DL_FUNC) &project_inv, 5},
+    {"project_ng", (DL_FUNC) &project_ng, 7},
+    {"project_ng_coordOp", (DL_FUNC) &project_ng_coordOp, 2},
+    {"CRS_compare", (DL_FUNC) &CRS_compare, 4},
+    {"proj_network_enabled", (DL_FUNC) &proj_network_enabled, 0},
     {"RGDAL_SetGeoTransform", (DL_FUNC) &RGDAL_SetGeoTransform, 2},
     {"RGDAL_GetNoDataValue", (DL_FUNC) &RGDAL_GetNoDataValue, 1},
     {"RGDAL_GetMetadata", (DL_FUNC) &RGDAL_GetMetadata, 2},
@@ -81,6 +91,7 @@ static R_CallMethodDef CallEntries[] = {
     {"RGDAL_GetRAT", (DL_FUNC) &RGDAL_GetRAT, 1},
     {"RGDAL_GetBandNoDataValue", (DL_FUNC) &RGDAL_GetBandNoDataValue, 1},
     {"RGDAL_SetProject", (DL_FUNC) &RGDAL_SetProject, 2},
+    {"RGDAL_SetProject_WKT2", (DL_FUNC) &RGDAL_SetProject_WKT2, 3},
     {"RGDAL_SetNoDataValue", (DL_FUNC) &RGDAL_SetNoDataValue, 2},
     {"RGDAL_SetStatistics", (DL_FUNC) &RGDAL_SetStatistics, 2},
     {"RGDAL_SetRasterColorTable", (DL_FUNC) &RGDAL_SetRasterColorTable, 4},
