@@ -14,6 +14,7 @@
 extern "C" {
 #endif
 /* #include <projects.h> */
+#ifndef PROJ_H_API
 #include <proj_api.h>
 /* BDR 131123 */
 #ifndef P4CTX
@@ -34,6 +35,10 @@ FILE *pj_open_lib(const char *, const char *);
 int inversetest(void *);
 #endif
 
+#if PJ_VERSION >= 600
+# define PROJ6 1
+#endif
+
 SEXP
 PROJ4VersionInfo(void) {
     SEXP ans;
@@ -125,8 +130,56 @@ PROJ4_proj_def_dat_Installed(void) {
 
 #define MAX_LINE_LEN 512	/* maximal line length supported.     */
 
+#ifndef PROJ6
+
+SEXP get_proj_search_path(void) {
+    Rprintf("Not available for PROJ version < 6");
+    return(R_NilValue);
+}
+
+
+SEXP list_coordinate_ops(SEXP source, SEXP target, SEXP area_of_interest, SEXP strict_containment, SEXP viz_order) {
+    Rprintf("Not available for PROJ version < 6");
+    return(R_NilValue);
+}
+
+SEXP CRS_compare(SEXP fromargs, SEXP toargs, SEXP type1, SEXP type2) {
+    Rprintf("Not available for PROJ version < 6");
+    return(R_NilValue);
+}
+
+SEXP transform_ng(SEXP fromargs, SEXP toargs, SEXP coordOp, SEXP npts, SEXP x, SEXP y, SEXP z) {
+    Rprintf("Not available for PROJ version < 6");
+    return(R_NilValue);
+}
+
+SEXP project_ng(SEXP n, SEXP xlon, SEXP ylat, SEXP zz, SEXP inv, SEXP ob_tran, SEXP coordOp) {
+    Rprintf("Not available for PROJ version < 6");
+    return(R_NilValue);
+}
+
+SEXP project_ng_coordOp(SEXP proj, SEXP inv) {
+    Rprintf("Not available for PROJ version < 6");
+    return(R_NilValue);
+}
+
+SEXP proj_network_enabled() {
+//    Rprintf("Not available for PROJ version < 7");
+    return(R_NilValue);
+}
+
+
+/*SEXP P6_SRID_proj(SEXP inSRID, SEXP format, SEXP multiline, SEXP in_format,
+    SEXP epsg, SEXP out_format) {
+
+    return(R_NilValue);
+
+}*/
+
+
 SEXP
 PROJcopyEPSG(SEXP tf) {
+
     SEXP ans;
 
 #if PJ_VERSION <= 480
@@ -205,6 +258,8 @@ PROJcopyEPSG(SEXP tf) {
 
     return(ans);
 }
+#endif
+
 
 SEXP RGDAL_project(SEXP n, SEXP xlon, SEXP ylat, SEXP projarg, SEXP ob_tran) {
 //void project(int *n, double *xlon, double *ylat, double *x, double *y, char **projarg, int *ob_tran){
@@ -498,6 +553,8 @@ SEXP RGDAL_checkCRSArgs(SEXP args) {
 	return(res);
 }
 
+#ifndef PROJ6
+
 /* #include <projects.h> */
 struct PJconsts;
     
@@ -531,6 +588,7 @@ struct PJ_UNITS {
 };
 struct PJ_UNITS *pj_get_units_ref( void );
 
+
 SEXP RGDAL_projInfo(SEXP type) {
     SEXP ans=NULL;
     SEXP ansnames;
@@ -613,7 +671,7 @@ SEXP RGDAL_projInfo(SEXP type) {
         }
 
     } else if (INTEGER_POINTER(type)[0] == 3) {
-#if PJ_VERSION < 500
+#if PJ_VERSION < 500 
         PROTECT(ans = NEW_LIST(3)); pc++;
         PROTECT(ansnames = NEW_CHARACTER(3)); pc++;
         SET_STRING_ELT(ansnames, 0, COPY_TO_USER_STRING("id"));
@@ -621,19 +679,19 @@ SEXP RGDAL_projInfo(SEXP type) {
         SET_STRING_ELT(ansnames, 2, COPY_TO_USER_STRING("name"));
         setAttrib(ans, R_NamesSymbol, ansnames);
 
-        struct PJ_UNITS *ld;
-        for (ld = pj_get_units_ref(); ld->id ; ++ld) n++;
+        struct PJ_UNITS *lu;
+        for (lu = pj_get_units_ref(); lu->id ; ++lu) n++;
         SET_VECTOR_ELT(ans, 0, NEW_CHARACTER(n));
         SET_VECTOR_ELT(ans, 1, NEW_CHARACTER(n));
         SET_VECTOR_ELT(ans, 2, NEW_CHARACTER(n));
         n=0;
-        for (ld = pj_get_units_ref(); ld->id ; ++ld) {
+        for (lu = pj_get_units_ref(); lu->id ; ++lu) {
             SET_STRING_ELT(VECTOR_ELT(ans, 0), n, 
-		COPY_TO_USER_STRING(ld->id));
+		COPY_TO_USER_STRING(lu->id));
             SET_STRING_ELT(VECTOR_ELT(ans, 1), n, 
-		COPY_TO_USER_STRING(ld->to_meter));
+		COPY_TO_USER_STRING(lu->to_meter));
             SET_STRING_ELT(VECTOR_ELT(ans, 2), n, 
-		COPY_TO_USER_STRING(ld->name));
+		COPY_TO_USER_STRING(lu->name));
             n++;
         }
 #else
@@ -645,21 +703,21 @@ SEXP RGDAL_projInfo(SEXP type) {
         SET_STRING_ELT(ansnames, 3, COPY_TO_USER_STRING("factor"));
         setAttrib(ans, R_NamesSymbol, ansnames);
 
-        struct PJ_UNITS *ld;
-        for (ld = pj_get_units_ref(); ld->id ; ++ld) n++;
+        struct PJ_UNITS *lu;
+        for (lu = pj_get_units_ref(); lu->id ; ++lu) n++;
         SET_VECTOR_ELT(ans, 0, NEW_CHARACTER(n));
         SET_VECTOR_ELT(ans, 1, NEW_CHARACTER(n));
         SET_VECTOR_ELT(ans, 2, NEW_CHARACTER(n));
         SET_VECTOR_ELT(ans, 3, NEW_NUMERIC(n));
         n=0;
-        for (ld = pj_get_units_ref(); ld->id ; ++ld) {
+        for (lu = pj_get_units_ref(); lu->id ; ++lu) {
             SET_STRING_ELT(VECTOR_ELT(ans, 0), n, 
-		COPY_TO_USER_STRING(ld->id));
+		COPY_TO_USER_STRING(lu->id));
             SET_STRING_ELT(VECTOR_ELT(ans, 1), n, 
-		COPY_TO_USER_STRING(ld->to_meter));
+		COPY_TO_USER_STRING(lu->to_meter));
             SET_STRING_ELT(VECTOR_ELT(ans, 2), n, 
-		COPY_TO_USER_STRING(ld->name));
-            NUMERIC_POINTER(VECTOR_ELT(ans, 3))[n] = ld->factor;
+		COPY_TO_USER_STRING(lu->name));
+            NUMERIC_POINTER(VECTOR_ELT(ans, 3))[n] = lu->factor;
             n++;
         }
 #endif
@@ -668,7 +726,9 @@ SEXP RGDAL_projInfo(SEXP type) {
     UNPROTECT(pc);
     return(ans);
 }
+#endif
 
+#endif // not PROJ_H_API 
 
 #ifdef __cplusplus
 }
